Class: TgVizor::Transport::Result
- Inherits:
-
Struct
- Object
- Struct
- TgVizor::Transport::Result
- Defined in:
- lib/tgvizor/transport.rb
Overview
Outcome of a single send attempt.
Instance Attribute Summary collapse
-
#message ⇒ String?
Human-readable error message.
-
#ok ⇒ Boolean
True on 202 Accepted.
-
#retryable ⇒ Boolean
True if the caller should persist and retry later.
-
#status ⇒ Integer?
HTTP status code, if any.
Instance Method Summary collapse
Instance Attribute Details
#message ⇒ String?
Returns human-readable error message.
24 25 26 |
# File 'lib/tgvizor/transport.rb', line 24 Result = Struct.new(:ok, :retryable, :status, :message, keyword_init: true) do def ok? = ok end |
#ok ⇒ Boolean
Returns true on 202 Accepted.
24 25 26 |
# File 'lib/tgvizor/transport.rb', line 24 Result = Struct.new(:ok, :retryable, :status, :message, keyword_init: true) do def ok? = ok end |
#retryable ⇒ Boolean
Returns true if the caller should persist and retry later.
24 25 26 |
# File 'lib/tgvizor/transport.rb', line 24 Result = Struct.new(:ok, :retryable, :status, :message, keyword_init: true) do def ok? = ok end |
#status ⇒ Integer?
Returns HTTP status code, if any.
24 25 26 |
# File 'lib/tgvizor/transport.rb', line 24 Result = Struct.new(:ok, :retryable, :status, :message, keyword_init: true) do def ok? = ok end |
Instance Method Details
#ok? ⇒ Boolean
25 |
# File 'lib/tgvizor/transport.rb', line 25 def ok? = ok |